@@ -12,7 +12,7 @@ def config_equals(a, b):
         return False
     if a.get('database') != b.get('database'):
         return False
-    if a.get('hostname') != b.get('hostname'):
+    if a.get('host') != b.get('host'):
         return False
 
     return True
